%
% $Id: show_wgt.sl,v 1.2 2001/10/22 16:17:22 dburke Exp $
%
% Script:
%   show_wgt.sl
%
% Aim:
%   simple graphical display of some of the columns of the 
%   weight file created by mkwarf.
%
% Thread:
%   http://cxc.harvard.edu/ciao/threads/wresp_multiple_sources/
%
% CIAO version:
%   2.2
%
% Usage:
%  show_wgt( filename )
%
% where filename is the name of a file created by the CIAO tool
% mkwarf.
%
% Examples:
%
%   If sources.wgt is the weights file created by mkwarf (ie the
%   weightfile parameter), then you can use either
%
%     unix% chips --slscript show_wgt.sl
%     chips> show_wgt( "sources.wgt" )
%
%   or
%
%     chips> () = evalfile( "show_wgt.sl" )
%     chips> lc_clean( "show_wgt" )
%
% Notes:
%   There is very little error checking - ie we assume the input
%   file is a weights file, and not some random file.
%
% To do:
%

define show_wgt(filename) {

    % we assume the file sent in is a weight file
    % - ie no error-checking
    variable wgt = readfile( filename );
    if ( wgt == NULL )
        error( "** ERROR **\n Unable to read data from " + 
            string(filename) );

    % plot the graph
    variable old_chips = @chips;
    set_state_defaults( "chips" );
    chips.symbolstyle = _chips->block;

    () = chips_eval( "redraw off" );
    () = chips_eval( "clear" );
    () = curve( wgt.REGNUM, wgt.CONTRIB );
    () = chips_eval( "ylabel CONTRIB" );

    () = chips_eval( "split 2" );
    () = chips_eval( "d 1 tickvals x off" );

    () = chips_eval( "d 2" );
    () = curve( wgt.REGNUM, wgt.FRACTION );
    () = chips_eval( "ylabel FRACTION" );
    () = chips_eval( "xlabel REGNUM" );

    % add the file name as the title (protect any
    % underscores, otherwise they'll be treated like
    % LaTeX commands) 
    variable title;
    ( title, ) = strreplace( filename, "_", "\\_", strlen(filename) );
    () = chips_eval( "title 'weights file: " + title + "'" );
    () = chips_eval( "title size 1.2" );

    () = chips_eval( "redraw on" );
    set_state( "chips", old_chips );

} % show_wgt()

